Band-mapping data classes  ``(mpes.bandstructure)``
=====================================================
Axis-linked data structure for multidimensional data based on ``xarray.DataArray``.

.. automodule:: mpes.bandstructure
   :members:
   :private-members: